#
# spec file for package dippi
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dippi
Version:        2.7.4
Release:        bp155.2.15
Summary:        Tool for calculating display info like DPI and aspect ratio
License:        GPL-3.0-or-later
Group:          System/GUI/Other
URL:            https://cassidyjames.com/dippi
Source:         https://github.com/cassidyjames/dippi/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  AppStream
BuildRequires:  fdupes
BuildRequires:  gettext-runtime >= 0.19.7
BuildRequires:  hicolor-icon-theme
BuildRequires:  libxml2-tools
BuildRequires:  meson >= 0.40.0
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(granite)
BuildRequires:  pkgconfig(gtk+-3.0)
Recommends:     %{name}-lang

%description
A tool to analyze displays and to input a few details and figure out the aspect
ratio, DPI, and other details of a particular display. Can be used to decide
which laptop or external monitor to purchase, and if it would be considered
HiDPI.

%lang_package

%prep
%setup -q

%build
%meson
%meson_build

%install
%meson_install
%suse_update_desktop_file -r com.github.cassidyjames.dippi GTK Utility DesktopSettings
%find_lang com.github.cassidyjames.dippi %{name}.lang
%fdupes %{buildroot}/%{_datadir}

# dirlist HiDPI icons (see: hicolor/index.theme)
_dirlist=$PWD/dir.lst
pushd %{buildroot}
find ./ | while read _list; do
    echo $_list | grep '[0-9]\@[0-9]' || continue
    _path=$(echo $_list | sed 's/[^/]//')
    if ! ls ${_path%/*}; then
        grep -xqs "\%dir\ ${_path%/*}" $_dirlist || echo "%dir ${_path%/*}" >> $_dirlist
    fi
done
popd

%files -f dir.lst
%doc AUTHORS COPYING README.md
%{_bindir}/com.github.cassidyjames.dippi
%{_datadir}/applications/com.github.cassidyjames.dippi.desktop
%{_datadir}/icons/hicolor/*/apps/com.github.cassidyjames.dippi.??g
%{_datadir}/metainfo/com.github.cassidyjames.dippi.appdata.xml

%files lang -f %{name}.lang

%changelog
* Wed Feb 19 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.7.4:
  * Create release.yml
  * Create lint.yml
  * Create gettext.yml
  * Create compress-images.yml
  * Remove debian packaging from in-tree
  * Update .travis.yml
  * Prefer dark (#72)
  * Update com.github.cassidyjames.dippi.appdata.xml.in (#71)
* Mon Apr 15 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.7.3:
  * Updated translations
* Wed Jan  9 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.7.2:
  * Comment out problematic "contact" url for now
  * Update com.github.cassidyjames.dippi.appdata.xml.in
  * Add help and contact URLs
  * Add donation URL
  * Fix app-id & add some missings tags (#68)
* Mon Nov 19 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.7.1:
  * Support dark preference if it exists (#66)
  * Update README.md
* Sun Jul  1 2018 avvissu@yandex.by
- Update to 2.7.0:
  * Whitespace fixes
- Switch to metainfo from appdata
* Sun Jun 10 2018 jengelh@inai.de
- Use noun phrasing in descriptions.
* Sat Apr 21 2018 avvissu@yandex.by
- Update to 2.6.3:
  * Update appdata
* Sat Apr 14 2018 avvissu@yandex.by
- Update to 2.6.2:
  * Update lt.po (#62)
* Mon Mar 26 2018 avvissu@yandex.by
- Update to 2.6.1:
  * Fix deprecation warning for set accel
  * Prep for tiny release
  * Clear Resolution Label when invalid (#61)
  * Prep for new release (#60)
  * Missed one
  * Force update to new badges
  * Split out into Utils (#58)
  * Fix error in appdata and bump version
  * Fix editoronfig
  * Actually update travis deps
  * Better editorconfig
  * Add editorconfig
* Fri Feb  9 2018 avvissu@yandex.by
- Update to 2.5.4:
  * Update README.md
  * Update com.github.cassidyjames.dippi.appdata.xml.in
  * Update appdata with new release
  * Set a size of the main grid (#53)
  * Prepare for new release
  * Add process-completed to GResource
* Sat Jan 20 2018 avvissu@yandex.by
- Update to 2.5.1:
  * Prep appdata for new release
  * Actually add all icon sizes
  * Try out new ranges
  * Add OARS data
  * Update es.po (#48)
- Add the package with translations
* Mon Jan 15 2018 avvissu@yandex.by
- Initial package
